pub struct ListBrandsResponse {
pub brands: Option<Vec<Brand>>,
}Expand description
Response message for ListBrands.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- brands list projects (response)
Fields
brands: Option<Vec<Brand>>Brands existing in the project.