pub struct TunnelDestGroup {
pub cidrs: Option<Vec<String>>,
pub fqdns: Option<Vec<String>>,
pub name: Option<String>,
}Expand description
A TunnelDestGroup.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- iap_tunnel locations dest groups create projects (request|response)
- iap_tunnel locations dest groups get projects (response)
- iap_tunnel locations dest groups patch projects (request|response)
Fields
cidrs: Option<Vec<String>>Optional. Unordered list. List of CIDRs that this group applies to.
fqdns: Option<Vec<String>>Optional. Unordered list. List of FQDNs that this group applies to.
name: Option<String>Identifier. Identifier for the TunnelDestGroup. Must be unique within the project and contain only lower case letters (a-z) and dashes (-).